Skip to contents

Animate a depth dependent timeseries from a Dlf file

Usage

animate_dlf(dlf, x_var = NULL, y_var = "z", time_var = "time")

Arguments

dlf

An S4 object of class Dlf

x_var

Name of variable on x axis. If NULL assume it is the column that is not y_var or time_var

y_var

Name of variable on y axis

time_var

Name of time variable

Value

A plotly figure

Examples

data_dir <- system.file("extdata", package="daisyrVis")
path <- file.path(data_dir, "daily/DailyP/DailyP-Daily-WaterFlux.dlf")
dlf <- read_dlf(path)
animate_dlf(dlf, "q")