Animate a depth dependent timeseries from a Dlf file
animate_dlf.RdAnimate a depth dependent timeseries from a Dlf file
Examples
data_dir <- system.file("extdata", package="daisyrVis")
path <- file.path(data_dir, "daily/DailyP/DailyP-Daily-WaterFlux.dlf")
dlf <- read_dlf(path)
animate_dlf(dlf, "q")